async fn find_by_upstream_id(
conn: &mut PgConnection,
query: &str,
) -> ChatbotResult<Vec<UserDetail>>Expand description
Looks up one user by upstream_id, rejecting a query that is not an integer.
async fn find_by_upstream_id(
conn: &mut PgConnection,
query: &str,
) -> ChatbotResult<Vec<UserDetail>>Looks up one user by upstream_id, rejecting a query that is not an integer.