pub struct FindUserArguments {
query: String,
kind: FindUserKind,
}Fields
query: Stringkind: FindUserKindTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FindUserArguments
Manual, not derived: kind needs validation #[derive(Deserialize)] can’t express, and this
is what ChatbotTool::Arguments’s DeserializeOwned bound is satisfied by (parse_arguments
below is overridden and never calls it, but the bound still has to hold).
impl<'de> Deserialize<'de> for FindUserArguments
Manual, not derived: kind needs validation #[derive(Deserialize)] can’t express, and this
is what ChatbotTool::Arguments’s DeserializeOwned bound is satisfied by (parse_arguments
below is overridden and never calls it, but the bound still has to hold).
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more